summaryrefslogtreecommitdiff
path: root/deps/v8/src/heap/combined-heap.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/src/heap/combined-heap.h')
-rw-r--r--deps/v8/src/heap/combined-heap.h20
1 files changed, 9 insertions, 11 deletions
diff --git a/deps/v8/src/heap/combined-heap.h b/deps/v8/src/heap/combined-heap.h
index c331d95c3d..eaa012ec18 100644
--- a/deps/v8/src/heap/combined-heap.h
+++ b/deps/v8/src/heap/combined-heap.h
@@ -13,21 +13,19 @@ namespace v8 {
namespace internal {
// This class allows iteration over the entire heap (Heap and ReadOnlyHeap). It
-// uses the HeapIterator to iterate over non-read-only objects and accepts the
-// same filtering option. (Interrupting iteration while filtering unreachable
-// objects is still forbidden)
-class V8_EXPORT_PRIVATE CombinedHeapIterator final {
+// uses the HeapObjectIterator to iterate over non-read-only objects and accepts
+// the same filtering option. (Interrupting iteration while filtering
+// unreachable objects is still forbidden)
+class V8_EXPORT_PRIVATE CombinedHeapObjectIterator final {
public:
- CombinedHeapIterator(Heap* heap,
- HeapIterator::HeapObjectsFiltering filtering =
- HeapIterator::HeapObjectsFiltering::kNoFiltering)
- : heap_iterator_(heap, filtering),
- ro_heap_iterator_(heap->read_only_heap()) {}
+ CombinedHeapObjectIterator(
+ Heap* heap, HeapObjectIterator::HeapObjectsFiltering filtering =
+ HeapObjectIterator::HeapObjectsFiltering::kNoFiltering);
HeapObject Next();
private:
- HeapIterator heap_iterator_;
- ReadOnlyHeapIterator ro_heap_iterator_;
+ HeapObjectIterator heap_iterator_;
+ ReadOnlyHeapObjectIterator ro_heap_iterator_;
};
V8_WARN_UNUSED_RESULT inline bool IsValidHeapObject(Heap* heap,